/**
 *
 * This does not convert non-utf8 strings to utf8, it only passes through strings if
 * a string is received instead of a Uint8Array.
 *
 */
export declare const toUtf8: (input: Uint8Array | string) => string;
